pub struct RecordSize {
pub record_size: u16,
pub extended_record_size: u16,
}Expand description
Size of the Crash Log record
Fields
record_size: u16Size of the main section of the record in dwords
extended_record_size: u16Size of the extended section of the record in dwords
Implementations
Sourceimpl RecordSize
impl RecordSize
Sourcepub fn from_slice(slice: &[u8]) -> Option<Self>
pub fn from_slice(slice: &[u8]) -> Option<Self>
Creates a RecordSize from the raw record
Sourcepub fn from_slice_type0_legacy_server(slice: &[u8]) -> Option<Self>
pub fn from_slice_type0_legacy_server(slice: &[u8]) -> Option<Self>
Creates a RecordSize from the raw record of a server product with legacy header type0